rm(list=ls(all=TRUE))

##Set working directory manually or using the following commands##
#getwd()
#setwd("pathway")

## read and attach the ANCOVA data, then center the predictor variable
ancova_data <- read.table("potentials.txt", header=T)
attach(ancova_data)
X <- as.numeric(scale(X))

### PART I: ANCOVA with built-in R functions ###

## use the lm() function and notice that order matters in ANCOVA

## model1 is the correct way to specify an ANCOVA
model1 <- lm(Y ~ X * Group)
anova(model1)

## model2 is incorrect: the continuous variable should go first
model2 <- lm(Y ~ Group * X)
anova(model2)

## Because the interaction appears to be insignificant, we remove it
model3 <- lm(Y ~ X + Group)
anova(model3)
summary(model3)

### PART II: Plotting the ANCOVA results ###

## obtain the coefficients and the slope & intercepts for each Group
summary.lm(model3)
coeffs <- summary.lm(model3)$coefficients
slope <- coeffs[2,1]
intercept1 <- coeffs[1,1]
intercept2 <- intercept1 + coeffs[3,1]
intercept3 <- intercept1 + coeffs[4,1]
intercept4 <- intercept1 + coeffs[5,1]

## split the covariate and response data based on Group
split_X_pts <- split(X, Group)
split_Y_pts <- split(Y, Group)

## plot the observations for each group
plot(X, Y, type="n", ylab= "Membrane potential", xlab="Log of activity ratio")
plot_chars <- c(16, 4, 7, 1)
legend("topleft", inset=0.05, legend=levels(Group), pch=plot_chars,col=c("blue","red","green","black"))
points(split_X_pts[[1]], split_Y_pts[[1]], pch=plot_chars[1],col="blue")
points(split_X_pts[[2]], split_Y_pts[[2]], pch=plot_chars[2],col="red")
points(split_X_pts[[3]], split_Y_pts[[3]], pch=plot_chars[3],col="green")
points(split_X_pts[[4]], split_Y_pts[[4]], pch=plot_chars[4],col="black")

## plot the regression lines for each group
abline(intercept1, slope, lty=1,col="blue")
abline(intercept2, slope, lty=2,col="red")
abline(intercept3, slope, lty=3,col="green")
abline(intercept4, slope, lty=4,col="black")

### PART III: ANCOVA using OpenBUGS ###

## Call package  
library(R2OpenBUGS)
n_obs <- length(Group)
z <-c(rep(1,4), rep(2,5), rep(3,6), rep(4,6))

### Fitting the model
# Write model
Ancova<-function()
## Priors
{
    c ~ dnorm(0,1.0E-6)
 for (i in 1:4)
   {
     a[i] ~ dnorm(0,1.0E-6)
   }
 tau ~ dgamma(0.001,0.001)

## Likelihood
 for (i in 1:n)
   {
   mean[i] <- a[z[i]] + c*x[i]
   Y[i]  ~ dnorm(mean[i],tau)
   }
  }
write.model(Ancova,"Ancova.txt")

# Bundle data
win.data <- list(Y=Y,x=X,z=z, n=n_obs)

# Inits function
inits <- function() 
   list(a=c(0,0,0,0), c=0, tau=runif(1))

# Parameters to estimate
params <- c("a","c")

# MCMC settings
nc = 3 
ni=50000
nb=5000
nt=100

# Start Gibbs sampler
out <- bugs(data = win.data, inits = inits, parameters = params, model = "Ancova.txt",
n.thin = nt, n.chains = nc, n.burnin = nb, n.iter = ni, codaPkg = TRUE, digits=5)
library(coda)
reg.coda<-read.bugs(out)
results<-summary(reg.coda)
results

## detach the data
detach(ancova_data)
